@@ -2,7 +2,7 @@ from urllib.parse import urljoin
 
 from django.core.exceptions import ValidationError
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from solo.models import SingletonModel
 
@@ -11,7 +11,7 @@ class CamundaConfig(SingletonModel):
     enabled = models.BooleanField(
         _("enabled"),
         default=True,
-        help_text=_("Global flag to enable/disable Camund integration."),
+        help_text=_("Global flag to enable/disable Camunda integration."),
     )
     root_url = models.URLField(
         _("camunda root"),
